# MACE: MetAl Complexes Embedding

Python library and command-line tool for generation of 3D coordinates for complexes of d-/f-elements.

## Installation

Create new conda environment with [RDKit](http://anaconda.org/rdkit/rdkit) 2020.03.1 or later:

```
> conda create -n mace
> conda install -c rdkit rdkit=2020.09.1
```

Next activate the environment install mace package using pip:

```
> conda activate mace
> pip install mace=0.2
```

Enjoy!

## Usage

See the *tests/demo.py* for the representative examples. Command-line interface is under development.
